/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.examples.resource;

import java.io.File;

import javax.servlet.Servlet;

import org.apithefire.servlet.embedded.ResourceServlet;
import org.apithefire.servlet.examples.util.ExamplesUtil;
import org.apithefire.servlet.jetty.JettyServer;
import org.apithefire.servlet.server.Server;
import org.apithefire.util.lang.Platform;
import org.apithefire.util.resource.Resource;
import org.apithefire.util.resource.Resources;

public class DirectoryListingExample {
	
	private DirectoryListingExample() {
	}

	public static void main(String[] args) {
		int port = ExamplesUtil.findUnusedPort();
		Server server = createServer(port);

		server.start();
		ExamplesUtil.launchBrowser(port);
		server.join();
	}
	
	private static Server createServer(int port) {
		Resource baseResource = createBaseResource();
		Servlet resourceServlet = ResourceServlet.newBuilder()
				.setBaseResource(baseResource)
				.setDirectoryListing(true)
				.setIndexFileName(null)
				.setBaseResourceName("Directory Listing Example")
				.build();
		Server server = JettyServer.newBuilder()
				.addConnector(port)
				.addContext(resourceServlet)
				.build();
		
		return server;
	}
	
	private static Resource createBaseResource() {
		Platform platform = Platform.getInstance();
		String userName = platform.getUserName();
		File userHomeDir = platform.getUserHomeDirectory();
		Resource baseResource = Resources.newDirectoryBuilder()
				.setResource(userName + "'s home directory", Resources.fromFile(userHomeDir))
				.setResource("classes", Resources.fromClassPath())
				.build();
		
		return baseResource;
	}
	
}
