/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.examples.swing;

import java.awt.BorderLayout;
import java.awt.Font;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;

public class Console extends JFrame {
	
	private static final int MAX_CHARS = 80000;
	private static Console instance;
	
    private final JTextArea textArea;

    public static Console getInstance() {
    	if (instance == null) {
    		instance = new Console();
    	}
    	return instance;
    }
    
    private Console() {
    	this.textArea = createTextArea();

		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        getContentPane().add(new JScrollPane(textArea), BorderLayout.CENTER);
		this.setLocationByPlatform(true);
        pack();
    }
    
    private static JTextArea createTextArea() {
    	JTextArea textArea = new JTextArea();
    	
        textArea.setEditable(false);
        textArea.setRows(20);
        textArea.setColumns(100);
        textArea.setFont(new Font("Courier New", Font.PLAIN, 14));
        return textArea;
    }
    
    public void appendText(String text) {
    	textArea.append(text);
    }
    
    public void scrollToBottom() {
    	Document doc = textArea.getDocument();
    	
    	if (doc.getLength() > MAX_CHARS) {
    		try {
				doc.remove(0, doc.getLength() - MAX_CHARS);
			} catch (BadLocationException e) {
				throw new RuntimeException(e);
			}
    	}
    	textArea.setCaretPosition(doc.getLength());
    }

}
