/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.examples.wicket;

import javax.servlet.Filter;
import javax.servlet.Servlet;

import org.apache.wicket.Page;
import org.apache.wicket.protocol.http.WebApplication;
import org.apithefire.servlet.embedded.FilteredServlet;
import org.apithefire.servlet.embedded.ResourceServlet;
import org.apithefire.servlet.examples.util.ExamplesUtil;
import org.apithefire.servlet.jetty.JettyServer;
import org.apithefire.servlet.server.Server;
import org.apithefire.servlet.wicket.AbstractWebApplication;
import org.apithefire.servlet.wicket.EmbeddedWicketFilter;
import org.apithefire.util.lang.Path;
import org.apithefire.util.resource.Resource;
import org.apithefire.util.resource.Resources;

public class ResourceAndWicketFilterExample {

	public static class HomePage extends BlueBlogPage {

		public HomePage() {
		}

		@Override
		protected String getTitle() {
			return "Resource and Wicket Filter Example";
		}

		@Override
		protected String getDescription() {
			return ExamplesUtil.loadResource(getClass(),
					"ResourceAndWicketFilterExampleDescription.txt");
		}

		@Override
		protected String getCode() {
			return ExamplesUtil.loadResource(getClass(),
					"ResourceAndWicketFilterExampleCode.txt");
		}

	}

	public static void main(String[] args) {
		int port = ExamplesUtil.findUnusedPort();
		Server server = createServer(port);

		server.start();
		ExamplesUtil.launchBrowser(port);
		server.join();
	}
	
	private static Server createServer(int port) {
		WebApplication webApp = new AbstractWebApplication() {
			@Override
			public Class<? extends Page> getHomePage() {
				return HomePage.class;
			}
		};
		Servlet resourceServlet = ResourceServlet.newBuilder()
				.setBaseResource(createBaseResource())
				.build();
		Filter wicketFilter = new EmbeddedWicketFilter(webApp, Path.EMPTY_PATH);
		Servlet filteredServlet = FilteredServlet.newBuilder()
				.addFilter(wicketFilter)
				.setServlet(resourceServlet)
				.build();
		Server server = JettyServer.newBuilder()
				.addConnector(port)
				.addContext(filteredServlet)
				.build();
		
		return server;
	}
	
	private static Resource createBaseResource() {
		Resource about = Resources.newFileBuilder()
				.setContent("This is a static resource.")
				.build();
		return Resources.newDirectoryBuilder()
				.setResource("static_resource.txt", about)
				.build();
	}

}
